# Safe deployment abci

## Description

This module contains the ABCI safe deployment skill for an AEA.

## Behaviours

* `DeploySafeBehaviour`

   Deploy Safe.

* `RandomnessSafeBehaviour`

   Retrieve randomness for oracle deployment.

* `SafeDeploymentBaseState`

   Base state behaviour for the common apps' skill.

* `SelectKeeperSafeBehaviour`

   Select the keeper agent.

* `ValidateSafeBehaviour`

   Validate Safe.


## Handlers

No Handlers (the skill is purely behavioural).

